@@ -7,14 +7,10 @@ var classnanovdb_1_1RootNode_1_1DenseIter =
     [ "getCoord", "classnanovdb_1_1RootNode_1_1DenseIter.html#aeeccd5dc4acad6e3ab10f3d228925897", null ],
     [ "getOrigin", "classnanovdb_1_1RootNode_1_1DenseIter.html#a7ac9aa9292e82e310f109d51b78d7d22", null ],
     [ "isValueOn", "classnanovdb_1_1RootNode_1_1DenseIter.html#ab299b5cc90869ef58d05042c4946600f", null ],
-    [ "next", "classnanovdb_1_1RootNode_1_1DenseIter.html#ae93f73f6ed1154e6df221ac6e1ed5cb6", null ],
     [ "operator bool", "classnanovdb_1_1RootNode_1_1DenseIter.html#aabac1f710a9cc519a171968ead10188f", null ],
     [ "operator++", "classnanovdb_1_1RootNode_1_1DenseIter.html#a710a6d7fe0b6f433275f3dce7de28b40", null ],
     [ "operator++", "classnanovdb_1_1RootNode_1_1DenseIter.html#a42a8d160d303284499e6c0f9219af22d", null ],
     [ "pos", "classnanovdb_1_1RootNode_1_1DenseIter.html#ab15fcffb10fddd7e1e6058c7aa6f650d", null ],
     [ "probeChild", "classnanovdb_1_1RootNode_1_1DenseIter.html#a243022e0f1cbd1cc3d9cbfcd036bf5a3", null ],
-    [ "tile", "classnanovdb_1_1RootNode_1_1DenseIter.html#aec08e8fd3fccf3fa4f773d132b6af6b0", null ],
-    [ "mData", "classnanovdb_1_1RootNode_1_1DenseIter.html#aaafe9474a398e87a776de6687ccb0ccd", null ],
-    [ "mPos", "classnanovdb_1_1RootNode_1_1DenseIter.html#a276f0c1d4ea76d5d30b536b1fe9ba66b", null ],
-    [ "mSize", "classnanovdb_1_1RootNode_1_1DenseIter.html#a42157cb6a88e23caba7f6e1e5f38e9f1", null ]
+    [ "tile", "classnanovdb_1_1RootNode_1_1DenseIter.html#aec08e8fd3fccf3fa4f773d132b6af6b0", null ]
 ];
\ No newline at end of file
