@@ -1,5 +1,66 @@
 var NAVTREEINDEX122 =
 {
+"structopenvdb_1_1v12__1_1_1points_1_1EllipsoidSettings.html#ae661a48c59f03d21951e848a42995473":[14,0,6,0,6,22,9],
+"structopenvdb_1_1v12__1_1_1points_1_1EllipsoidSettings.html#ae661a48c59f03d21951e848a42995473":[15,0,4,0,5,21,9],
+"structopenvdb_1_1v12__1_1_1points_1_1EllipsoidSettings.html#afbe01f0c6a8bf7f7a4e4fefbe50eaad8":[14,0,6,0,6,22,2],
+"structopenvdb_1_1v12__1_1_1points_1_1EllipsoidSettings.html#afbe01f0c6a8bf7f7a4e4fefbe50eaad8":[15,0,4,0,5,21,2],
+"structopenvdb_1_1v12__1_1_1points_1_1FilterTraits.html":[14,0,6,0,6,25],
+"structopenvdb_1_1v12__1_1_1points_1_1FilterTraits.html":[15,0,4,0,5,24],
+"structopenvdb_1_1v12__1_1_1points_1_1FilterTraits.html#ad30e154a3e9354f516875bfdc15a5a9e":[14,0,6,0,6,25,0],
+"structopenvdb_1_1v12__1_1_1points_1_1FilterTraits.html#ad30e154a3e9354f516875bfdc15a5a9e":[15,0,4,0,5,24,0],
+"structopenvdb_1_1v12__1_1_1points_1_1FilterTraits_3_01BBoxFilter_01_4.html":[14,0,6,0,6,26],
+"structopenvdb_1_1v12__1_1_1points_1_1FilterTraits_3_01BBoxFilter_01_4.html":[15,0,4,0,5,25],
+"structopenvdb_1_1v12__1_1_1points_1_1FilterTraits_3_01BBoxFilter_01_4.html#ad30e154a3e9354f516875bfdc15a5a9e":[14,0,6,0,6,26,0],
+"structopenvdb_1_1v12__1_1_1points_1_1FilterTraits_3_01BBoxFilter_01_4.html#ad30e154a3e9354f516875bfdc15a5a9e":[15,0,4,0,5,25,0],
+"structopenvdb_1_1v12__1_1_1points_1_1FilterTraits_3_01BinaryFilter_3_01T0_00_01T1_00_01And_01_4_01_4.html":[14,0,6,0,6,27],
+"structopenvdb_1_1v12__1_1_1points_1_1FilterTraits_3_01BinaryFilter_3_01T0_00_01T1_00_01And_01_4_01_4.html":[15,0,4,0,5,26],
+"structopenvdb_1_1v12__1_1_1points_1_1FilterTraits_3_01BinaryFilter_3_01T0_00_01T1_00_01And_01_4_01_4.html#ad30e154a3e9354f516875bfdc15a5a9e":[14,0,6,0,6,27,0],
+"structopenvdb_1_1v12__1_1_1points_1_1FilterTraits_3_01BinaryFilter_3_01T0_00_01T1_00_01And_01_4_01_4.html#ad30e154a3e9354f516875bfdc15a5a9e":[15,0,4,0,5,26,0],
+"structopenvdb_1_1v12__1_1_1points_1_1FilterTraits_3_01LevelSetFilter_3_01T_01_4_01_4.html":[14,0,6,0,6,28],
+"structopenvdb_1_1v12__1_1_1points_1_1FilterTraits_3_01LevelSetFilter_3_01T_01_4_01_4.html":[15,0,4,0,5,27],
+"structopenvdb_1_1v12__1_1_1points_1_1FilterTraits_3_01LevelSetFilter_3_01T_01_4_01_4.html#ad30e154a3e9354f516875bfdc15a5a9e":[14,0,6,0,6,28,0],
+"structopenvdb_1_1v12__1_1_1points_1_1FilterTraits_3_01LevelSetFilter_3_01T_01_4_01_4.html#ad30e154a3e9354f516875bfdc15a5a9e":[15,0,4,0,5,27,0],
+"structopenvdb_1_1v12__1_1_1points_1_1FilteredTransfer.html":[14,0,6,0,6,23],
+"structopenvdb_1_1v12__1_1_1points_1_1FilteredTransfer.html":[15,0,4,0,5,22],
+"structopenvdb_1_1v12__1_1_1points_1_1FilteredTransfer.html#a73bb2a1eb90f28e972582fec6e4d2eb6":[14,0,6,0,6,23,2],
+"structopenvdb_1_1v12__1_1_1points_1_1FilteredTransfer.html#a73bb2a1eb90f28e972582fec6e4d2eb6":[15,0,4,0,5,22,2],
+"structopenvdb_1_1v12__1_1_1points_1_1FilteredTransfer.html#ab52947af43d708abb63e572657155eb4":[14,0,6,0,6,23,4],
+"structopenvdb_1_1v12__1_1_1points_1_1FilteredTransfer.html#ab52947af43d708abb63e572657155eb4":[15,0,4,0,5,22,4],
+"structopenvdb_1_1v12__1_1_1points_1_1FilteredTransfer.html#adf51674704b039fbe64fb9b252677498":[14,0,6,0,6,23,0],
+"structopenvdb_1_1v12__1_1_1points_1_1FilteredTransfer.html#adf51674704b039fbe64fb9b252677498":[15,0,4,0,5,22,0],
+"structopenvdb_1_1v12__1_1_1points_1_1FilteredTransfer.html#ae59d6c37a06a9f925bc8c6fb515abe12":[14,0,6,0,6,23,3],
+"structopenvdb_1_1v12__1_1_1points_1_1FilteredTransfer.html#ae59d6c37a06a9f925bc8c6fb515abe12":[15,0,4,0,5,22,3],
+"structopenvdb_1_1v12__1_1_1points_1_1FilteredTransfer.html#aee1f430ba223609067e082214ecfd95e":[14,0,6,0,6,23,1],
+"structopenvdb_1_1v12__1_1_1points_1_1FilteredTransfer.html#aee1f430ba223609067e082214ecfd95e":[15,0,4,0,5,22,1],
+"structopenvdb_1_1v12__1_1_1points_1_1FilteredTransfer_3_01NullFilter_01_4.html":[14,0,6,0,6,24],
+"structopenvdb_1_1v12__1_1_1points_1_1FilteredTransfer_3_01NullFilter_01_4.html":[15,0,4,0,5,23],
+"structopenvdb_1_1v12__1_1_1points_1_1FilteredTransfer_3_01NullFilter_01_4.html#a7d6213f67ff6b1930f5bdedd8b5851f7":[14,0,6,0,6,24,1],
+"structopenvdb_1_1v12__1_1_1points_1_1FilteredTransfer_3_01NullFilter_01_4.html#a7d6213f67ff6b1930f5bdedd8b5851f7":[15,0,4,0,5,23,1],
+"structopenvdb_1_1v12__1_1_1points_1_1FilteredTransfer_3_01NullFilter_01_4.html#aa30f1b4683e0efe851ccbeb29c496dc6":[14,0,6,0,6,24,0],
+"structopenvdb_1_1v12__1_1_1points_1_1FilteredTransfer_3_01NullFilter_01_4.html#aa30f1b4683e0efe851ccbeb29c496dc6":[15,0,4,0,5,23,0],
+"structopenvdb_1_1v12__1_1_1points_1_1FilteredTransfer_3_01NullFilter_01_4.html#ae59d6c37a06a9f925bc8c6fb515abe12":[14,0,6,0,6,24,2],
+"structopenvdb_1_1v12__1_1_1points_1_1FilteredTransfer_3_01NullFilter_01_4.html#ae59d6c37a06a9f925bc8c6fb515abe12":[15,0,4,0,5,23,2],
+"structopenvdb_1_1v12__1_1_1points_1_1FilteredTransfer_3_01NullFilter_01_4.html#ae606d39748c3a43b44681ed988f64476":[14,0,6,0,6,24,3],
+"structopenvdb_1_1v12__1_1_1points_1_1FilteredTransfer_3_01NullFilter_01_4.html#ae606d39748c3a43b44681ed988f64476":[15,0,4,0,5,23,3],
+"structopenvdb_1_1v12__1_1_1points_1_1FixedPointCodec.html":[14,0,6,0,6,29],
+"structopenvdb_1_1v12__1_1_1points_1_1FixedPointCodec.html":[15,0,4,0,5,28],
+"structopenvdb_1_1v12__1_1_1points_1_1FixedPointCodec.html#a2d6494d59c2e5fab0d0a0ba207c7e420":[14,0,6,0,6,29,2],
+"structopenvdb_1_1v12__1_1_1points_1_1FixedPointCodec.html#a2d6494d59c2e5fab0d0a0ba207c7e420":[15,0,4,0,5,28,2],
+"structopenvdb_1_1v12__1_1_1points_1_1FixedPointCodec.html#a4af770a447fa44ae0c9b216adcb83783":[14,0,6,0,6,29,1],
+"structopenvdb_1_1v12__1_1_1points_1_1FixedPointCodec.html#a4af770a447fa44ae0c9b216adcb83783":[15,0,4,0,5,28,1],
+"structopenvdb_1_1v12__1_1_1points_1_1FixedPointCodec.html#a80926f21b03253a1045be08235e9d6ea":[14,0,6,0,6,29,3],
+"structopenvdb_1_1v12__1_1_1points_1_1FixedPointCodec.html#a80926f21b03253a1045be08235e9d6ea":[15,0,4,0,5,28,3],
+"structopenvdb_1_1v12__1_1_1points_1_1FixedPointCodec_1_1Storage.html":[14,0,6,0,6,29,0],
+"structopenvdb_1_1v12__1_1_1points_1_1FixedPointCodec_1_1Storage.html":[15,0,4,0,5,28,0],
+"structopenvdb_1_1v12__1_1_1points_1_1FixedPointCodec_1_1Storage.html#aed757c70f826b97933db46ae98abf58c":[14,0,6,0,6,29,0,0],
+"structopenvdb_1_1v12__1_1_1points_1_1FixedPointCodec_1_1Storage.html#aed757c70f826b97933db46ae98abf58c":[15,0,4,0,5,28,0,0],
+"structopenvdb_1_1v12__1_1_1points_1_1FrustumRasterizerMask.html":[14,0,6,0,6,31],
+"structopenvdb_1_1v12__1_1_1points_1_1FrustumRasterizerMask.html":[15,0,4,0,5,30],
+"structopenvdb_1_1v12__1_1_1points_1_1FrustumRasterizerMask.html#a47363949b6f580f29f6069ca6a4d28a0":[14,0,6,0,6,31,1],
+"structopenvdb_1_1v12__1_1_1points_1_1FrustumRasterizerMask.html#a47363949b6f580f29f6069ca6a4d28a0":[15,0,4,0,5,30,1],
+"structopenvdb_1_1v12__1_1_1points_1_1FrustumRasterizerMask.html#a67b76affb3b5d35fa419ac234144038b":[14,0,6,0,6,31,5],
+"structopenvdb_1_1v12__1_1_1points_1_1FrustumRasterizerMask.html#a67b76affb3b5d35fa419ac234144038b":[15,0,4,0,5,30,5],
+"structopenvdb_1_1v12__1_1_1points_1_1FrustumRasterizerMask.html#a69c5065a8757f39603ccb2209fb3b725":[14,0,6,0,6,31,6],
 "structopenvdb_1_1v12__1_1_1points_1_1FrustumRasterizerMask.html#a69c5065a8757f39603ccb2209fb3b725":[15,0,4,0,5,30,6],
 "structopenvdb_1_1v12__1_1_1points_1_1FrustumRasterizerMask.html#a878afc49edc6e61f0b3b62f6e796b1f5":[14,0,6,0,6,31,0],
 "structopenvdb_1_1v12__1_1_1points_1_1FrustumRasterizerMask.html#a878afc49edc6e61f0b3b62f6e796b1f5":[15,0,4,0,5,30,0],
@@ -188,66 +249,5 @@ var NAVTREEINDEX122 =
 "structopenvdb_1_1v12__1_1_1points_1_1SphereSettings.html#ab5e6d33a91cf19de9c9638df85aad6a2":[14,0,6,0,6,54,0],
 "structopenvdb_1_1v12__1_1_1points_1_1SphereSettings.html#ab5e6d33a91cf19de9c9638df85aad6a2":[15,0,4,0,5,53,0],
 "structopenvdb_1_1v12__1_1_1points_1_1SphereSettings.html#ae000837070c3f223000ee300b37cc0d2":[14,0,6,0,6,54,8],
-"structopenvdb_1_1v12__1_1_1points_1_1SphereSettings.html#ae000837070c3f223000ee300b37cc0d2":[15,0,4,0,5,53,8],
-"structopenvdb_1_1v12__1_1_1points_1_1StringCodec.html":[14,0,6,0,6,57],
-"structopenvdb_1_1v12__1_1_1points_1_1StringCodec.html":[15,0,4,0,5,56],
-"structopenvdb_1_1v12__1_1_1points_1_1StringCodec.html#a3b612e00f00edc0cb8a31e946612e227":[14,0,6,0,6,57,3],
-"structopenvdb_1_1v12__1_1_1points_1_1StringCodec.html#a3b612e00f00edc0cb8a31e946612e227":[15,0,4,0,5,56,3],
-"structopenvdb_1_1v12__1_1_1points_1_1StringCodec.html#a56dd0190eeb05bc8c2bbfbcb30eb20b1":[14,0,6,0,6,57,2],
-"structopenvdb_1_1v12__1_1_1points_1_1StringCodec.html#a56dd0190eeb05bc8c2bbfbcb30eb20b1":[15,0,4,0,5,56,2],
-"structopenvdb_1_1v12__1_1_1points_1_1StringCodec.html#a80926f21b03253a1045be08235e9d6ea":[14,0,6,0,6,57,4],
-"structopenvdb_1_1v12__1_1_1points_1_1StringCodec.html#a80926f21b03253a1045be08235e9d6ea":[15,0,4,0,5,56,4],
-"structopenvdb_1_1v12__1_1_1points_1_1StringCodec.html#aead646b20bdbc305bd284c2692420735":[14,0,6,0,6,57,1],
-"structopenvdb_1_1v12__1_1_1points_1_1StringCodec.html#aead646b20bdbc305bd284c2692420735":[15,0,4,0,5,56,1],
-"structopenvdb_1_1v12__1_1_1points_1_1StringCodec_1_1Storage.html":[14,0,6,0,6,57,0],
-"structopenvdb_1_1v12__1_1_1points_1_1StringCodec_1_1Storage.html":[15,0,4,0,5,56,0],
-"structopenvdb_1_1v12__1_1_1points_1_1StringCodec_1_1Storage.html#aacfb84cc1131fe7873c5ff865fb484e6":[14,0,6,0,6,57,0,0],
-"structopenvdb_1_1v12__1_1_1points_1_1StringCodec_1_1Storage.html#aacfb84cc1131fe7873c5ff865fb484e6":[15,0,4,0,5,56,0,0],
-"structopenvdb_1_1v12__1_1_1points_1_1TransformTransfer.html":[14,0,6,0,6,60],
-"structopenvdb_1_1v12__1_1_1points_1_1TransformTransfer.html":[15,0,4,0,5,59],
-"structopenvdb_1_1v12__1_1_1points_1_1TransformTransfer.html#a2ff8c68d2ded92b64092f380f09b5e99":[14,0,6,0,6,60,4],
-"structopenvdb_1_1v12__1_1_1points_1_1TransformTransfer.html#a2ff8c68d2ded92b64092f380f09b5e99":[15,0,4,0,5,59,4],
-"structopenvdb_1_1v12__1_1_1points_1_1TransformTransfer.html#a38c93c93ec35397933cfc680837b329f":[14,0,6,0,6,60,1],
-"structopenvdb_1_1v12__1_1_1points_1_1TransformTransfer.html#a38c93c93ec35397933cfc680837b329f":[15,0,4,0,5,59,1],
-"structopenvdb_1_1v12__1_1_1points_1_1TransformTransfer.html#a932e0e057527f168144493598d09e9fc":[14,0,6,0,6,60,2],
-"structopenvdb_1_1v12__1_1_1points_1_1TransformTransfer.html#a932e0e057527f168144493598d09e9fc":[15,0,4,0,5,59,2],
-"structopenvdb_1_1v12__1_1_1points_1_1TransformTransfer.html#aba4675d91ec246a3e7caf71d8474bbb6":[14,0,6,0,6,60,3],
-"structopenvdb_1_1v12__1_1_1points_1_1TransformTransfer.html#aba4675d91ec246a3e7caf71d8474bbb6":[15,0,4,0,5,59,3],
-"structopenvdb_1_1v12__1_1_1points_1_1TransformTransfer.html#af0adf292877ed1cd7955bd4c752dc12e":[14,0,6,0,6,60,0],
-"structopenvdb_1_1v12__1_1_1points_1_1TransformTransfer.html#af0adf292877ed1cd7955bd4c752dc12e":[15,0,4,0,5,59,0],
-"structopenvdb_1_1v12__1_1_1points_1_1TreeConverter.html":[14,0,6,0,6,61],
-"structopenvdb_1_1v12__1_1_1points_1_1TreeConverter.html":[15,0,4,0,5,60],
-"structopenvdb_1_1v12__1_1_1points_1_1TreeConverter.html#a1eb35dc2018c16c50c3acc3f324994ed":[14,0,6,0,6,61,2],
-"structopenvdb_1_1v12__1_1_1points_1_1TreeConverter.html#a1eb35dc2018c16c50c3acc3f324994ed":[15,0,4,0,5,60,2],
-"structopenvdb_1_1v12__1_1_1points_1_1TreeConverter.html#a68942c81d3596303af14433171a84671":[14,0,6,0,6,61,1],
-"structopenvdb_1_1v12__1_1_1points_1_1TreeConverter.html#a68942c81d3596303af14433171a84671":[15,0,4,0,5,60,1],
-"structopenvdb_1_1v12__1_1_1points_1_1TreeConverter.html#adfea44bbb2ff0e212f42e6349a481701":[14,0,6,0,6,61,0],
-"structopenvdb_1_1v12__1_1_1points_1_1TreeConverter.html#adfea44bbb2ff0e212f42e6349a481701":[15,0,4,0,5,60,0],
-"structopenvdb_1_1v12__1_1_1points_1_1TrilinearTraits.html":[14,0,6,0,6,62],
-"structopenvdb_1_1v12__1_1_1points_1_1TrilinearTraits.html":[15,0,4,0,5,61],
-"structopenvdb_1_1v12__1_1_1points_1_1TrilinearTraits.html#a12f94a74865352d1982a942696aaec5a":[14,0,6,0,6,62,0],
-"structopenvdb_1_1v12__1_1_1points_1_1TrilinearTraits.html#a12f94a74865352d1982a942696aaec5a":[15,0,4,0,5,61,0],
-"structopenvdb_1_1v12__1_1_1points_1_1TrilinearTraits.html#ab55ba77318ce95ce0e6d070a74926905":[14,0,6,0,6,62,1],
-"structopenvdb_1_1v12__1_1_1points_1_1TrilinearTraits.html#ab55ba77318ce95ce0e6d070a74926905":[15,0,4,0,5,61,1],
-"structopenvdb_1_1v12__1_1_1points_1_1TrilinearTraits_3_01ValueT_00_01false_01_4.html":[14,0,6,0,6,63],
-"structopenvdb_1_1v12__1_1_1points_1_1TrilinearTraits_3_01ValueT_00_01false_01_4.html":[15,0,4,0,5,62],
-"structopenvdb_1_1v12__1_1_1points_1_1TrilinearTraits_3_01ValueT_00_01false_01_4.html#ab55ba77318ce95ce0e6d070a74926905":[14,0,6,0,6,63,1],
-"structopenvdb_1_1v12__1_1_1points_1_1TrilinearTraits_3_01ValueT_00_01false_01_4.html#ab55ba77318ce95ce0e6d070a74926905":[15,0,4,0,5,62,1],
-"structopenvdb_1_1v12__1_1_1points_1_1TrilinearTraits_3_01ValueT_00_01false_01_4.html#aba729b2454aced2e6bc449daaadb4816":[14,0,6,0,6,63,0],
-"structopenvdb_1_1v12__1_1_1points_1_1TrilinearTraits_3_01ValueT_00_01false_01_4.html#aba729b2454aced2e6bc449daaadb4816":[15,0,4,0,5,62,0],
-"structopenvdb_1_1v12__1_1_1points_1_1TruncateCodec.html":[14,0,6,0,6,64],
-"structopenvdb_1_1v12__1_1_1points_1_1TruncateCodec.html":[15,0,4,0,5,63],
-"structopenvdb_1_1v12__1_1_1points_1_1TruncateCodec.html#a2d6494d59c2e5fab0d0a0ba207c7e420":[14,0,6,0,6,64,2],
-"structopenvdb_1_1v12__1_1_1points_1_1TruncateCodec.html#a2d6494d59c2e5fab0d0a0ba207c7e420":[15,0,4,0,5,63,2],
-"structopenvdb_1_1v12__1_1_1points_1_1TruncateCodec.html#a4af770a447fa44ae0c9b216adcb83783":[14,0,6,0,6,64,1],
-"structopenvdb_1_1v12__1_1_1points_1_1TruncateCodec.html#a4af770a447fa44ae0c9b216adcb83783":[15,0,4,0,5,63,1],
-"structopenvdb_1_1v12__1_1_1points_1_1TruncateCodec.html#a80926f21b03253a1045be08235e9d6ea":[14,0,6,0,6,64,3],
-"structopenvdb_1_1v12__1_1_1points_1_1TruncateCodec.html#a80926f21b03253a1045be08235e9d6ea":[15,0,4,0,5,63,3],
-"structopenvdb_1_1v12__1_1_1points_1_1TruncateCodec_1_1Storage.html":[14,0,6,0,6,64,0],
-"structopenvdb_1_1v12__1_1_1points_1_1TruncateCodec_1_1Storage.html":[15,0,4,0,5,63,0],
-"structopenvdb_1_1v12__1_1_1points_1_1TruncateCodec_1_1Storage.html#ac4cf505f17fd0af0359f5451a1cbbdef":[14,0,6,0,6,64,0,0],
-"structopenvdb_1_1v12__1_1_1points_1_1TruncateCodec_1_1Storage.html#ac4cf505f17fd0af0359f5451a1cbbdef":[15,0,4,0,5,63,0,0],
-"structopenvdb_1_1v12__1_1_1points_1_1UnitRange.html":[14,0,6,0,6,66],
-"structopenvdb_1_1v12__1_1_1points_1_1UnitRange.html":[15,0,4,0,5,65],
-"structopenvdb_1_1v12__1_1_1points_1_1UnitRange.html#a396dfdab259d148dd01bc1e5ee58c282":[14,0,6,0,6,66,0]
+"structopenvdb_1_1v12__1_1_1points_1_1SphereSettings.html#ae000837070c3f223000ee300b37cc0d2":[15,0,4,0,5,53,8]
 };
