@@ -1,5 +1,62 @@
 var NAVTREEINDEX85 =
 {
+"overview.html#secGrid":[3,5],
+"overview.html#secIterator":[3,7],
+"overview.html#secOverview":[3,1],
+"overview.html#secSpaceAndTrans":[3,4],
+"overview.html#secSparsity":[3,3],
+"overview.html#secToolUtils":[3,6],
+"overview.html#secTree":[3,2],
+"overview.html#subsecInactive":[3,3,1],
+"overview.html#subsecNodeIter":[3,7,1],
+"overview.html#subsecTrans":[3,4,2],
+"overview.html#subsecTraversal":[3,7,3],
+"overview.html#subsecTreeConfig":[3,2,0],
+"overview.html#subsecTreeIter":[3,7,0],
+"overview.html#subsecValueAccessor":[3,7,2],
+"overview.html#subsecValues":[3,3,0],
+"overview.html#subsecVoxSpace":[3,4,0],
+"overview.html#subsecWorSpace":[3,4,1],
+"pages.html":[],
+"pnanovdb__validate__strides_8h.html":[16,0,1,1,0],
+"pnanovdb__validate__strides_8h.html#a5ae96574b59f94b1ba8a95b7fb6f968c":[16,0,1,1,0,2],
+"pnanovdb__validate__strides_8h.html#a72dd2ef42b0df1c3d9dfb69fb9f0bb68":[16,0,1,1,0,1],
+"pnanovdb__validate__strides_8h.html#a955497afb4d8c4f347d53b859fc9f310":[16,0,1,1,0,0],
+"pnanovdb__validate__strides_8h.html#a9dc8f7a00235750a6b3674bbdd025501":[16,0,1,1,0,3],
+"pnanovdb__validate__strides_8h.html#ad462c36333078816f0ba72b089f8f2db":[16,0,1,1,0,4],
+"pnanovdb__validate__strides_8h_source.html":[16,0,1,1,0],
+"points.html":[7],
+"points.html":[0,0],
+"points.html#secPtActiveValues":[7,6,1],
+"points.html#secPtActiveValues":[0,0,6,1],
+"points.html#secPtAttributeHandle":[7,4,1],
+"points.html#secPtAttributeHandle":[0,0,4,1],
+"points.html#secPtAttributePerformance":[7,4,2],
+"points.html#secPtAttributePerformance":[0,0,4,2],
+"points.html#secPtAttributeSet":[7,4,3],
+"points.html#secPtAttributeSet":[0,0,4,3],
+"points.html#secPtAttributes":[7,4],
+"points.html#secPtAttributes":[0,0,4],
+"points.html#secPtBackground":[7,6,0],
+"points.html#secPtBackground":[0,0,6,0],
+"points.html#secPtCompression":[7,2],
+"points.html#secPtCompression":[0,0,2],
+"points.html#secPtContents":[7,0],
+"points.html#secPtContents":[0,0,0],
+"points.html#secPtIndexFilters":[7,6,3],
+"points.html#secPtIndexFilters":[0,0,6,3],
+"points.html#secPtIndexIterators":[7,6,2],
+"points.html#secPtIndexIterators":[0,0,6,2],
+"points.html#secPtLocality":[7,3],
+"points.html#secPtLocality":[0,0,3],
+"points.html#secPtOverview":[7,1],
+"points.html#secPtOverview":[0,0,1],
+"points.html#secPtPointDataTree":[7,5,1],
+"points.html#secPtPointDataTree":[0,0,5,1],
+"points.html#secPtPointIndexTree":[7,5,0],
+"points.html#secPtPointIndexTree":[0,0,5,0],
+"points.html#secPtPointTree":[7,5],
+"points.html#secPtPointTree":[0,0,5],
 "points.html#secPtSpaceAndTrans":[7,7],
 "points.html#secPtSpaceAndTrans":[0,0,7],
 "points.html#secPtSparsity":[7,6],
@@ -192,62 +249,5 @@ var NAVTREEINDEX85 =
 "structcnanovdb__node2F3.html#ae67cef59d3bd11a984ceb04e4520a012":[15,0,23,7],
 "structcnanovdb__readaccessor.html":[15,0,24],
 "structcnanovdb__readaccessor.html#a1da022828f25a21fb67342d13eecd987":[15,0,24,1],
-"structcnanovdb__readaccessor.html#aaaefef2b27370de62c8bd1f1ffa32947":[15,0,24,0],
-"structcnanovdb__rootdataF.html":[15,0,27],
-"structcnanovdb__rootdataF.html#a4518d8f98f7460166325c5b43c823605":[15,0,27,7],
-"structcnanovdb__rootdataF.html#a47848965cfc2281831d5ee70116c20f9":[15,0,27,8],
-"structcnanovdb__rootdataF.html#a5abbf0d39de519a363053d36c61824fd":[15,0,27,3],
-"structcnanovdb__rootdataF.html#a97181a4552f4240ece7960f12ddf7c8e":[15,0,27,1],
-"structcnanovdb__rootdataF.html#a9fcfd40a12f3e22c608f8ca5c9f88f9e":[15,0,27,6],
-"structcnanovdb__rootdataF.html#aba9e59125aa66f2496d27901d16e7b8b":[15,0,27,4],
-"structcnanovdb__rootdataF.html#ad3cc34d255b15b4929afb076b0f6277d":[15,0,27,2],
-"structcnanovdb__rootdataF.html#ade2d78ed03b0f82108603a3dc045d46c":[15,0,27,0],
-"structcnanovdb__rootdataF.html#ae29e8a0048f0fc600b2459cc0bf19dec":[15,0,27,5],
-"structcnanovdb__rootdataF3.html":[15,0,28],
-"structcnanovdb__rootdataF3.html#a1d84277d9fba352d389960306f0fc5bf":[15,0,28,0],
-"structcnanovdb__rootdataF3.html#a3f52b13777b9e9f16ac7fee9427b19bd":[15,0,28,2],
-"structcnanovdb__rootdataF3.html#a4518d8f98f7460166325c5b43c823605":[15,0,28,7],
-"structcnanovdb__rootdataF3.html#a47848965cfc2281831d5ee70116c20f9":[15,0,28,8],
-"structcnanovdb__rootdataF3.html#a5abbf0d39de519a363053d36c61824fd":[15,0,28,3],
-"structcnanovdb__rootdataF3.html#a97181a4552f4240ece7960f12ddf7c8e":[15,0,28,1],
-"structcnanovdb__rootdataF3.html#aba9e59125aa66f2496d27901d16e7b8b":[15,0,28,4],
-"structcnanovdb__rootdataF3.html#ad6282bb1e3459f5dd68786c640572252":[15,0,28,5],
-"structcnanovdb__rootdataF3.html#ae67cef59d3bd11a984ceb04e4520a012":[15,0,28,6],
-"structcnanovdb__rootdata__tileF.html":[15,0,25],
-"structcnanovdb__rootdata__tileF.html#a17956fe0129d3d4c94ebc06cfef2ad82":[15,0,25,4],
-"structcnanovdb__rootdata__tileF.html#a1b0c7bd4d79798ef4e0ce23894c9aeb2":[15,0,25,3],
-"structcnanovdb__rootdata__tileF.html#a4e4bbe123f9db761ae1dc943cfd6ff4b":[15,0,25,0],
-"structcnanovdb__rootdata__tileF.html#ab889bf192829d81b14acffa5b10e9df3":[15,0,25,2],
-"structcnanovdb__rootdata__tileF.html#ada8e43aa83e951688779f3735fb6fa7d":[15,0,25,1],
-"structcnanovdb__rootdata__tileF3.html":[15,0,26],
-"structcnanovdb__rootdata__tileF3.html#a1b0c7bd4d79798ef4e0ce23894c9aeb2":[15,0,26,3],
-"structcnanovdb__rootdata__tileF3.html#a3d567a3b5d210d5b814f79c72df59ef2":[15,0,26,4],
-"structcnanovdb__rootdata__tileF3.html#ab889bf192829d81b14acffa5b10e9df3":[15,0,26,2],
-"structcnanovdb__rootdata__tileF3.html#ad1590631764aa865d7b4e329dac10122":[15,0,26,0],
-"structcnanovdb__rootdata__tileF3.html#ada8e43aa83e951688779f3735fb6fa7d":[15,0,26,1],
-"structcnanovdb__treedata.html":[15,0,31],
-"structcnanovdb__treedata.html#a33270b24338e577f743ab910d2df0128":[15,0,31,2],
-"structcnanovdb__treedata.html#a33bd473158fe89c48e4f76151d70161d":[15,0,31,0],
-"structcnanovdb__treedata.html#aa311448d0c7ee358b79707c037f93957":[15,0,31,1],
-"structcnanovdb__treedata.html#adc59639a6130794b729e8b8a6c740e89":[15,0,31,3],
-"structcnanovdb__treedata.html#afcf2b031d9a2b4255e1131f36820a7b7":[15,0,31,4],
-"structcxx14_1_1index__sequence.html":[14,0,0,0],
-"structcxx14_1_1index__sequence.html":[15,0,0,0],
-"structcxx14_1_1make__index__sequence.html":[14,0,0,1],
-"structcxx14_1_1make__index__sequence.html":[15,0,0,1],
-"structcxx14_1_1make__index__sequence_3_010_00_01Is_8_8_8_01_4.html":[14,0,0,2],
-"structcxx14_1_1make__index__sequence_3_010_00_01Is_8_8_8_01_4.html":[15,0,0,2],
-"structnanovdb_1_1BitArray.html":[14,0,5,2],
-"structnanovdb_1_1BitArray.html":[15,0,3,2],
-"structnanovdb_1_1BitArray_3_0116_01_4.html":[14,0,5,3],
-"structnanovdb_1_1BitArray_3_0116_01_4.html":[15,0,3,3],
-"structnanovdb_1_1BitArray_3_0116_01_4.html#ae2251e09460138f434f445cab7824c08":[14,0,5,3,0],
-"structnanovdb_1_1BitArray_3_0116_01_4.html#ae2251e09460138f434f445cab7824c08":[15,0,3,3,0],
-"structnanovdb_1_1BitArray_3_0132_01_4.html":[14,0,5,4],
-"structnanovdb_1_1BitArray_3_0132_01_4.html":[15,0,3,4],
-"structnanovdb_1_1BitArray_3_0132_01_4.html#a0251ac0c51aa69a1a5f25044b269eae1":[14,0,5,4,0],
-"structnanovdb_1_1BitArray_3_0132_01_4.html#a0251ac0c51aa69a1a5f25044b269eae1":[15,0,3,4,0],
-"structnanovdb_1_1BitArray_3_0164_01_4.html":[14,0,5,5],
-"structnanovdb_1_1BitArray_3_0164_01_4.html":[15,0,3,5],
-"structnanovdb_1_1BitArray_3_0164_01_4.html#af3e2644dc8b717cc20da528c6de31cb3":[14,0,5,5,0]
+"structcnanovdb__readaccessor.html#aaaefef2b27370de62c8bd1f1ffa32947":[15,0,24,0]
 };
