@@ -3,6 +3,5 @@ var searchData=
   ['define_5fiscached_0',['DEFINE_ISCACHED',['../CNanoVDB_8h.html#ae72f50dd2bec24d0ddb154b8c82e4ee2',1,'CNanoVDB.h']]],
   ['define_5fkey_1',['DEFINE_KEY',['../CNanoVDB_8h.html#a33bb435c0d27f5a69909cb662459d61d',1,'CNanoVDB.h']]],
   ['definemask_2',['DEFINEMASK',['../CNanoVDB_8h.html#adf8eb564e0d6aa9c5576717e77ca9274',1,'CNanoVDB.h']]],
-  ['definemask_5fint_3',['DEFINEMASK_int',['../CNanoVDB_8h.html#a100cf82e5bd407bad721c62205511e62',1,'CNanoVDB.h']]],
-  ['dense_5fmagic_5fnumber_4',['DENSE_MAGIC_NUMBER',['../DenseGrid_8h.html#ad13c4070fe4ab75d817d2eef19552657',1,'DenseGrid.h']]]
+  ['definemask_5fint_3',['DEFINEMASK_int',['../CNanoVDB_8h.html#a100cf82e5bd407bad721c62205511e62',1,'CNanoVDB.h']]]
 ];
